# OCTAVVS release history

## 0.0.29

* Replaced dependency on opencv with scikit-image (needed only for making mask from polygon in MCR-ALS).
* Added dependency on xlwt as this is required for MS Excel export from Clustering.

## 0.0.28

* Added import of OPUS data files in Preprocessing, including white light image (experimental).

## 0.0.27

* First well-ordered release.
